@@ -224,7 +224,7 @@ class CGGoogleMaps extends CGExtensions
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '2.2.3';
+    return '2.2.7';
   }
 
 
@@ -343,7 +343,7 @@ EOT;
    ---------------------------------------------------------*/
   function MinimumCMSVersion()
   {
-    return "1.9.1";
+    return "1.9.4.2";
   }
 	
 	
