@@ -13,8 +13,8 @@ class cggm_address_lookup
 	$mod = cge_utils::get_module('CGGoogleMaps');
 	if( $mod )
 	  {
-	    self::$_lookup_service = $mod->GetPreference('address_lookup_service','GOOGLE');
-	    self::$_lookup_policy  = $mod->GetPreference('address_lookup_policy','CACHE');
+	    self::$_lookup_service = $mod->GetPreference('lookup_service','GOOGLE');
+	    self::$_lookup_policy  = $mod->GetPreference('lookup_policy','CACHE');
 	  }
       }
   }
@@ -58,14 +58,18 @@ class cggm_address_lookup
       default:
 	$address = str_replace('%20','+',rawurlencode($address));
 	//$address = str_replace(' ','+',$address);
-	$url = sprintf('http://maps.googleapis.com/maps/api/geocode/json?address=%s&sensor=false',$address);
-	$res = cge_http::get($url);
+	$url = sprintf('http://maps.googleapis.com/maps/api/geocode/json?sensor=false&address=%s',$address);
+	$res = cge_http::get($url,'',FALSE);
 	if( $res )
 	  {
 	    $tmp = json_decode($res);
-	    if( $tmp->status != 'OK' ) return FALSE;
+	    if( !isset($tmp->status) || $tmp->status != 'OK' )
+	      {
+		audit('','cggm_address_lookup','Address lookup of '.$address.' returned '.$tmp->status);
+		return FALSE;
+	      }
 	    if( !isset($tmp->results[0]->geometry->location) ) return FALSE;
-	    return array($tmp->results[0]->geometry->location->lat,$tmp->results[0]->geometry->location->lng);
+	    return array((float)$tmp->results[0]->geometry->location->lat,(float)$tmp->results[0]->geometry->location->lng);
 	  }
 	break;
       }
@@ -109,4 +113,4 @@ class cggm_address_lookup
 
 } // end of class
 
-?>
\ No newline at end of file
+?>
